@@ -50,10 +50,10 @@ typedef enum {
   NDPI_PROTOCOL_POSTGRES              = 19,
   NDPI_PROTOCOL_MYSQL                 = 20,
   NDPI_PROTOCOL_MS_OUTLOOK            = 21, /* Hotmail / Microsoft Outlook / Exchange */
-  NDPI_PROTOCOL_DIRECT_DOWNLOAD_LINK  = 22,
+  NDPI_PROTOCOL_VK                    = 22,
   NDPI_PROTOCOL_MAIL_POPS             = 23,
-  NDPI_PROTOCOL_APPLEJUICE            = 24,
-  NDPI_PROTOCOL_DIRECTCONNECT         = 25,
+  NDPI_PROTOCOL_TAILSCALE             = 24,
+  NDPI_PROTOCOL_YANDEX                = 25,
   NDPI_PROTOCOL_NTOP                  = 26,
   NDPI_PROTOCOL_COAP                  = 27,
   NDPI_PROTOCOL_VMWARE                = 28,
@@ -61,16 +61,16 @@ typedef enum {
   NDPI_PROTOCOL_DTLS                  = 30,
   NDPI_PROTOCOL_UBNTAC2               = 31, /* Ubiquity UBNT AirControl = 2 */
   NDPI_PROTOCOL_KONTIKI               = 32,
-  NDPI_PROTOCOL_OPENFT                = 33,
-  NDPI_PROTOCOL_FASTTRACK             = 34,
+  NDPI_PROTOCOL_YANDEX_MAIL           = 33,
+  NDPI_PROTOCOL_YANDEX_MUSIC          = 34,
   NDPI_PROTOCOL_GNUTELLA              = 35,
   NDPI_PROTOCOL_EDONKEY               = 36,
   NDPI_PROTOCOL_BITTORRENT            = 37,
-  NDPI_PROTOCOL_SKYPE_CALL            = 38, /* Skype call and videocalls */
+  NDPI_PROTOCOL_SKYPE_TEAMS_CALL      = 38, /* Skype call and videocalls */
   NDPI_PROTOCOL_SIGNAL                = 39,
   NDPI_PROTOCOL_MEMCACHED             = 40, /* Memcached */
   NDPI_PROTOCOL_SMBV23                = 41, /* SMB version 2/3 */
-  NDPI_PROTOCOL_MINING                = 42, /* Bitcoin, Ethereum, ZCash, Monero */
+  NDPI_PROTOCOL_MINING                = 42, /* Ethereum, ZCash, Monero */
   NDPI_PROTOCOL_NEST_LOG_SINK         = 43, /* Nest Log Sink (Nest Protect) */
   NDPI_PROTOCOL_MODBUS                = 44, /* Modbus */
   NDPI_PROTOCOL_WHATSAPP_CALL         = 45, /* WhatsApp video ad audio calls go here */
@@ -84,17 +84,17 @@ typedef enum {
   NDPI_PROTOCOL_CPHA                  = 53,
   NDPI_PROTOCOL_PPSTREAM              = 54,
   NDPI_PROTOCOL_ZATTOO                = 55,
-  NDPI_PROTOCOL_SHOUTCAST             = 56,
-  NDPI_PROTOCOL_SOPCAST               = 57,
+  NDPI_PROTOCOL_YANDEX_MARKET         = 56,
+  NDPI_PROTOCOL_YANDEX_DISK           = 57,
   NDPI_PROTOCOL_DISCORD               = 58,
   NDPI_PROTOCOL_TVUPLAYER             = 59,
   NDPI_PROTOCOL_MONGODB               = 60,
   NDPI_PROTOCOL_PLURALSIGHT           = 61,
-  NDPI_PROTOCOL_THUNDER               = 62,
+  NDPI_PROTOCOL_YANDEX_CLOUD          = 62,
   NDPI_PROTOCOL_OCSP                  = 63,
   NDPI_PROTOCOL_VXLAN                 = 64,
   NDPI_PROTOCOL_IRC                   = 65,
-  NDPI_PROTOCOL_AYIYA                 = 66,
+  NDPI_PROTOCOL_MERAKI_CLOUD          = 66,
   NDPI_PROTOCOL_JABBER                = 67,
   NDPI_PROTOCOL_NATS                  = 68,
   NDPI_PROTOCOL_AMONG_US              = 69,
@@ -107,7 +107,7 @@ typedef enum {
   NDPI_PROTOCOL_WORLDOFWARCRAFT       = 76,
   NDPI_PROTOCOL_TELNET                = 77,
   NDPI_PROTOCOL_STUN                  = 78,
-  NDPI_PROTOCOL_IP_IPSEC              = 79,
+  NDPI_PROTOCOL_IPSEC                 = 79,
   NDPI_PROTOCOL_IP_GRE                = 80,
   NDPI_PROTOCOL_IP_ICMP               = 81,
   NDPI_PROTOCOL_IP_IGMP               = 82,
@@ -126,8 +126,8 @@ typedef enum {
   NDPI_PROTOCOL_IAX                   = 95,
   NDPI_PROTOCOL_TFTP                  = 96,
   NDPI_PROTOCOL_AFP                   = 97,
-  NDPI_PROTOCOL_STEALTHNET            = 98,
-  NDPI_PROTOCOL_AIMINI                = 99,
+  NDPI_PROTOCOL_YANDEX_METRIKA        = 98,
+  NDPI_PROTOCOL_YANDEX_DIRECT         = 99,
   NDPI_PROTOCOL_SIP                   = 100,
   NDPI_PROTOCOL_TRUPHONE              = 101,
   NDPI_PROTOCOL_IP_ICMPV6             = 102,
@@ -135,8 +135,8 @@ typedef enum {
   NDPI_PROTOCOL_ARMAGETRON            = 104,
   NDPI_PROTOCOL_CROSSFIRE             = 105,
   NDPI_PROTOCOL_DOFUS                 = 106,
-  NDPI_PROTOCOL_FIESTA                = 107,
-  NDPI_PROTOCOL_FLORENSIA             = 108,
+  NDPI_PROTOCOL_ADS_ANALYTICS_TRACK   = 107, /* Generic id for advertisement/analytics/tracking stuff */
+  NDPI_PROTOCOL_ADULT_CONTENT         = 108,
   NDPI_PROTOCOL_GUILDWARS             = 109,
   NDPI_PROTOCOL_AMAZON_ALEXA          = 110,
   NDPI_PROTOCOL_KERBEROS              = 111,
@@ -319,6 +319,72 @@ typedef enum {
   NDPI_PROTOCOL_EDGECAST              = 288,
   NDPI_PROTOCOL_CACHEFLY              = 289,
   NDPI_PROTOCOL_SOFTETHER             = 290,
+  NDPI_PROTOCOL_MPEGDASH              = 291,
+  NDPI_PROTOCOL_DAZN                  = 292,
+  NDPI_PROTOCOL_GOTO                  = 293, /* GoTo products, mainly GoToMeeting */
+  NDPI_PROTOCOL_RSH                   = 294,
+  NDPI_PROTOCOL_1KXUN                 = 295,
+  NDPI_PROTOCOL_IP_PGM                = 296,
+  NDPI_PROTOCOL_IP_PIM                = 297,
+  NDPI_PROTOCOL_COLLECTD              = 298,
+  NDPI_PROTOCOL_TUNNELBEAR            = 299,
+  NDPI_PROTOCOL_CLOUDFLARE_WARP       = 300,
+  NDPI_PROTOCOL_I3D                   = 301, /* i3d.net: Game Hosting service */
+  NDPI_PROTOCOL_RIOTGAMES             = 302,
+  NDPI_PROTOCOL_PSIPHON               = 303,
+  NDPI_PROTOCOL_ULTRASURF             = 304,
+  NDPI_PROTOCOL_THREEMA               = 305,
+  NDPI_PROTOCOL_ALICLOUD              = 306,
+  NDPI_PROTOCOL_AVAST                 = 307,
+  NDPI_PROTOCOL_TIVOCONNECT           = 308,
+  NDPI_PROTOCOL_KISMET                = 309,
+  NDPI_PROTOCOL_FASTCGI               = 310,
+  NDPI_PROTOCOL_FTPS                  = 311,
+  NDPI_PROTOCOL_NATPMP                = 312,
+  NDPI_PROTOCOL_SYNCTHING             = 313,
+  NDPI_PROTOCOL_CRYNET                = 314,
+  NDPI_PROTOCOL_LINE                  = 315,
+  NDPI_PROTOCOL_LINE_CALL             = 316,
+  NDPI_PROTOCOL_APPLETVPLUS           = 317,
+  NDPI_PROTOCOL_DIRECTV               = 318,
+  NDPI_PROTOCOL_HBO                   = 319,
+  NDPI_PROTOCOL_VUDU                  = 320,
+  NDPI_PROTOCOL_SHOWTIME              = 321,
+  NDPI_PROTOCOL_DAILYMOTION           = 322,
+  NDPI_PROTOCOL_LIVESTREAM            = 323,
+  NDPI_PROTOCOL_TENCENTVIDEO          = 324,
+  NDPI_PROTOCOL_IHEARTRADIO           = 325,
+  NDPI_PROTOCOL_TIDAL                 = 326,
+  NDPI_PROTOCOL_TUNEIN                = 327,
+  NDPI_PROTOCOL_SIRIUSXMRADIO         = 328,
+  NDPI_PROTOCOL_MUNIN                 = 329,
+  NDPI_PROTOCOL_ELASTICSEARCH         = 330,
+  NDPI_PROTOCOL_TUYA_LP               = 331, /* TUYA LAN Protocol; IoT OS: https://github.com/tuya/tuya-iotos-embeded-sdk-wifi-ble-bk7231n */
+  NDPI_PROTOCOL_TPLINK_SHP            = 332, /* TP-LINK Smart Home Protocol */
+  NDPI_PROTOCOL_SOURCE_ENGINE         = 333,
+  NDPI_PROTOCOL_BACNET                = 334,
+  NDPI_PROTOCOL_OICQ                  = 335,
+  NDPI_PROTOCOL_HOTS                  = 336, /* Heroes of the Storm */
+  NDPI_PROTOCOL_FACEBOOK_REEL_STORY   = 337,
+  NDPI_PROTOCOL_SRTP                  = 338,
+  NDPI_PROTOCOL_OPERA_VPN             = 339,
+  NDPI_PROTOCOL_EPICGAMES             = 340,
+  NDPI_PROTOCOL_GEFORCENOW            = 341,
+  NDPI_PROTOCOL_NVIDIA                = 342,
+  NDPI_PROTOCOL_BITCOIN               = 343, 
+  NDPI_PROTOCOL_PROTONVPN             = 344,
+  NDPI_PROTOCOL_APACHE_THRIFT         = 345,
+  NDPI_PROTOCOL_ROBLOX                = 346,
+  NDPI_PROTOCOL_SERVICE_LOCATION      = 347,
+  NDPI_PROTOCOL_MULLVAD               = 348,
+  NDPI_PROTOCOL_HTTP2                 = 349,
+  NDPI_PROTOCOL_HAPROXY               = 350,
+  NDPI_PROTOCOL_RMCP                  = 351,
+  NDPI_PROTOCOL_CAN                   = 352,
+  NDPI_PROTOCOL_PROTOBUF              = 353,
+  NDPI_PROTOCOL_ETHEREUM              = 354, 
+  NDPI_PROTOCOL_TELEGRAM_VOIP         = 355,
+  NDPI_PROTOCOL_SINA_WEIBO	      = 356,	
 
 #ifdef CUSTOM_NDPI_PROTOCOLS
 #include "../../../nDPI-custom/custom_ndpi_protocol_ids.h"
